==> proc-10.1.59.tar.gz: proc/js/proc-pubkey-module.js <==
/**
 * Helper function for reading public keys from local storage and remote server
 *
 * @param drupalSettings
 * @param openpgp
 * @returns {Promise<Awaited<unknown>[]>}
 */
export async function procReadKey(drupalSettings, openpgp) {

  const recipientsPubkeys = [];
  const remoteKey = [];

  const recipientsUidsKeysChanged = JSON.parse(
    drupalSettings.proc_recipients_pubkeys_changed,
  );

  for (const userIdIterator in recipientsUidsKeysChanged) {
    const localKey = localStorage.getItem(
      `proc.key_user_id.${userIdIterator}.${recipientsUidsKeysChanged[userIdIterator]}`,
    );

    if (localKey) {
      console.info('Key found in local storage');
      recipientsPubkeys.push(localKey);
    } else {
      const storageKeys = Object.keys(localStorage);

      if (storageKeys.length > 0) {
        storageKeys.forEach(function(storageKey, storageKeyIndex) {
          if (
            storageKey.startsWith(
              `proc.key_user_id.${userIdIterator}`,
            )
          ) {
            localStorage.removeItem(storageKeys[storageKeyIndex]);
          }
        });
      }

      remoteKey.push(userIdIterator);
    }
  }

  let pubkeysJson;

  if (remoteKey.length > 0) {
    const remoteKeyCsv = remoteKey.join(',');

    const pubKeyAjax = async remoteKeyCsv => {
      const response = await fetch(
        `${window.location.origin +
        drupalSettings.basePath}api/proc/getpubkey/${remoteKeyCsv}/user_id`,
      );
      pubkeysJson = await response.json();

      if (pubkeysJson.pubkey.length > 0) {
        pubkeysJson.pubkey.forEach(function(pubkey, index) {
          recipientsPubkeys.push(pubkey.key);

          try {
            localStorage.setItem(
              `proc.key_user_id.${remoteKey[index]}.${pubkey.changed}`,
              pubkey.key,
            );
          } catch (error) {
            console.warn(error);
          }
        });
      }
    };

    await pubKeyAjax(remoteKeyCsv);
  }

  const publicKeys = await Promise.all(
    recipientsPubkeys.map(armoredKey =>
      openpgp.readKey({
        armoredKey,
      }),
    ),
  );

  return publicKeys;

}

==> proc-10.1.68.tar.gz: proc/js/proc-pubkey-module.js <==
/**
 * Helper function for reading public keys from local storage and remote server
 *
 * @param drupalSettings
 * @param openpgp
 * @returns {Promise<Awaited<unknown>[]>}
 */
export async function procReadKey(drupalSettings, openpgp) {

  const recipientsPubkeys = [];
  const remoteKey = [];

  const recipientsUidsKeysChanged = JSON.parse(
    drupalSettings.proc_recipients_pubkeys_changed,
  );

  for (const userIdIterator in recipientsUidsKeysChanged) {
    const localKey = localStorage.getItem(
      `proc.key_user_id.${userIdIterator}.${recipientsUidsKeysChanged[userIdIterator]}`,
    );

    if (localKey) {
      console.info('Key found in local storage');
      recipientsPubkeys.push(localKey);
    } else {
      const storageKeys = Object.keys(localStorage);

      if (storageKeys.length > 0) {
        storageKeys.forEach(function(storageKey, storageKeyIndex) {
          if (
            storageKey.startsWith(
              `proc.key_user_id.${userIdIterator}`,
            )
          ) {
            localStorage.removeItem(storageKeys[storageKeyIndex]);
          }
        });
      }

      remoteKey.push(userIdIterator);
    }
  }

  let pubkeysJson;

  if (remoteKey.length > 0) {
    const remoteKeyCsv = remoteKey.join(',');

    const pubKeyAjax = async remoteKeyCsv => {
      const response = await fetch(
        `${window.location.origin +
        drupalSettings.basePath}api/proc/getpubkey/${remoteKeyCsv}/user_id`,
      );
      pubkeysJson = await response.json();

      if (pubkeysJson.pubkey.length > 0) {
        pubkeysJson.pubkey.forEach(function(pubkey, index) {
          recipientsPubkeys.push(pubkey.key);

          try {
            localStorage.setItem(
              `proc.key_user_id.${remoteKey[index]}.${pubkey.changed}`,
              pubkey.key,
            );
          } catch (error) {
            console.warn(error);
          }
        });
      }
    };

    await pubKeyAjax(remoteKeyCsv);
  }

  return await Promise.all(
    recipientsPubkeys.map(armoredKey =>
      openpgp.readKey({
        armoredKey,
      }),
    ),
  );

}
